"use strict";

let data = "";

document.addEventListener("DOMContentLoaded", onPageLoaded);

function onPageLoaded()
{
	let storageSizeElement = document.getElementById("storage-size");

	// spinner for number of bytes

	let nCharsElem = document.getElementsByName("nChars")[0];
	nCharsElem.oninput = () => {
		data = "a".repeat(nCharsElem.value);
		let nBytes = data.length * 2;	// assumes wide char strings
		storageSizeElement.textContent = getSizeWithUnit(nBytes);
	};
	nCharsElem.oninput();	// force first time

	// save

	let saveToSyncButtonElem = document.getElementsByName("saveToSyncButton")[0];
	saveToSyncButtonElem.onclick = () => {
		console.log("saving!");

		// divide into different fields so as not to trigger Firefox's "Maximum bytes per object exceeded ([number of bytes] > 16384 Bytes.)"
		let chunks = {};
		let chunkIndex = 0;
		for (let i = 0, length = data.length; i < length; i += 1000, chunkIndex++) {
			chunks["p"+chunkIndex] = data.substring(i, i + 1000);
		}

		browser.storage.sync.clear().then(
			() => {
				console.log("All data was cleared from Sync!");
				browser.storage.sync.set(chunks).then(
					() => console.log("All data was saved in Sync!"),
					(error) => console.log("error setting: " + error)
				);
			},
			(error) => console.log("error clearing: " + error)
		);
	};

	// load

	let loadFromSyncButtonElem = document.getElementsByName("loadFromSyncButton")[0];
	loadFromSyncButtonElem.onclick = () =>
		browser.storage.sync.get().then(
			(data) => {
				let chunksList = [];
				let p;
				for (let i = 0; (p = data["p"+i]) !== undefined; i++) {
					chunksList.push(p);
				}
				let finalStr = chunksList.join("");
				console.log("loaded! has length " + finalStr.length);
			},
			(error) => console.log("error getting: " + error)
		);
}

function getSizeWithUnit(size)
{
	let unit = 0;
	while (size >= 1024 && unit <= 2) {
		size /= 1024;
		unit++;
	}

	size = Math.round(size);

	if (unit == 0) {
		return size + "B";
	} else if (unit == 1) {
		return size + "KB";
	} else if (unit == 2) {
		return size + "MB";
	} else {
		return size + "GB";
	}
}
